==> owncloud-9.0.3-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/systemtags/l10n/sl.js <==
OC.L10N.register(
    "systemtags",
    {
    "<strong>System tags</strong> for a file have been modified" : "<strong>Sistemske oznake</strong> datoteke so bile spremenjene",
    "%1$s assigned system tag %3$s" : "Uporabnik %1$s je dodelil sistemsko oznako %3$s",
    "%1$s unassigned system tag %3$s" : "Uporabnik %1$s je odstranil sistemsko oznako %3$s",
    "%1$s created system tag %2$s" : "Uporabnik %1$s je ustvaril sistemsko oznako %2$s",
    "%1$s deleted system tag %2$s" : "Uporabnik %1$s je izbrisal sistemsko oznako %2$s",
    "%1$s updated system tag %3$s to %2$s" : "Uporabnik %1$s je posodobil sistemsko oznako %3$s za %2$s",
    "%1$s assigned system tag %3$s to %2$s" : "Uporabnik %1$s je dodelil sistemsko oznako %3$s za %2$s",
    "%1$s unassigned system tag %3$s from %2$s" : "Uporabnik %1$s je prevzel sistemsko oznako %3$s od %2$s",
    "%s (not-assignable)" : "%s (nedodeljivo)",
    "%s (invisible)" : "%s (nevidno)",
    "Tags" : "Oznake",
    "Tagged files" : "Označene datoteke",
    "Select tags to filter by" : "Izbor oznak za filtriranje",
    "Please select tags to filter by" : "Izbor oznak za filtriranje",
    "No files found for the selected tags" : "Na izbrane oznake ni najdenih datotek",
    "No files in here" : "V mapi ni datotek",
    "No entries found in this folder" : "V tej mapi ni najdenih predmetov.",
    "Name" : "Ime",
    "Size" : "Velikost",
    "Modified" : "Spremenjeno"
},
"nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");

==> owncloud-9.1.0-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/systemtags/l10n/sl.js <==
OC.L10N.register(
    "systemtags",
    {
    "Tags" : "Oznake",
    "Tagged files" : "Označene datoteke",
    "Select tags to filter by" : "Izbor oznak za filtriranje",
    "Please select tags to filter by" : "Izbor oznak za filtriranje",
    "No files found for the selected tags" : "Na izbrane oznake ni najdenih datotek",
    "<strong>System tags</strong> for a file have been modified" : "<strong>Sistemske oznake</strong> datoteke so bile spremenjene",
    "You assigned system tag %3$s" : "Dodelili ste sistemsko oznako %3$s",
    "%1$s assigned system tag %3$s" : "Uporabnik %1$s je dodelil sistemsko oznako %3$s",
    "You unassigned system tag %3$s" : "Odstranili ste sistemsko oznako %3$s",
    "%1$s unassigned system tag %3$s" : "Uporabnik %1$s je odstranil sistemsko oznako %3$s",
    "You created system tag %2$s" : "Ustvarili ste sistemsko oznako %2$s",
    "%1$s created system tag %2$s" : "Uporabnik %1$s je ustvaril sistemsko oznako %2$s",
    "You deleted system tag %2$s" : "Izbrisali ste sistemsko oznako %2$s",
    "%1$s deleted system tag %2$s" : "Uporabnik %1$s je izbrisal sistemsko oznako %2$s",
    "You updated system tag %3$s to %2$s" : "Posodobili ste sistemsko oznako %3$s v %2$s",
    "%1$s updated system tag %3$s to %2$s" : "Uporabnik %1$s je posodobil sistemsko oznako %3$s za %2$s",
    "You assigned system tag %3$s to %2$s" : "Dodelili ste sistemsko oznako %3$s za %2$s",
    "%1$s assigned system tag %3$s to %2$s" : "Uporabnik %1$s je dodelil sistemsko oznako %3$s za %2$s",
    "You unassigned system tag %3$s from %2$s" : "Odstranili ste sistemsko oznako %3$s od %2$s",
    "%1$s unassigned system tag %3$s from %2$s" : "Uporabnik %1$s je prevzel sistemsko oznako %3$s od %2$s",
    "%s (restricted)" : "%s (omejeno)",
    "%s (invisible)" : "%s (nevidno)",
    "No files in here" : "V mapi ni datotek",
    "No entries found in this folder" : "V tej mapi ni najdenih predmetov.",
    "Name" : "Ime",
    "Size" : "Velikost",
    "Modified" : "Spremenjeno"
},
"nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");
